#!/bin/sh
###############################################################################
# BRLTTY - A background process providing access to the console screen (when in
#          text mode) for a blind person using a refreshable braille display.
#
# Copyright (C) 1995-2025 by The BRLTTY Developers.
#
# BRLTTY comes with ABSOLUTELY NO WARRANTY.
#
# This is free software, placed under the terms of the
# GNU Lesser General Public License, as published by the Free Software
# Foundation; either version 2.1 of the License, or (at your option) any
# later version. Please see the file LICENSE-LGPL for details.
#
# Web Page: http://brltty.app/
#
# This software is maintained by Dave Mielke <dave@mielke.cc>.
###############################################################################

listInstalledPackages() {
   pacman --query --native | awk '{print $1}'
}

installPackages() {
   pacman --sync --needed --quiet --noprogressbar --noconfirm -- "${@}"
}

removePackages() {
   pacman --remove --noprogressbar --noconfirm -- "${@}"
}

describePackage() {
   pacman --sync --info -- "${1}"
}

whichPackage() {
   pacman --files -- "${1}"
}

searchPackage() {
   pacman --sync --search -- "${1}"
}

